@@ -307,7 +307,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         X_t = self._component_graph.compute_final_component_features(X, y=y)
         return X_t
 
-    def avm(self, X, batch_sample_sets=1, latest_production_version=1, max_sample_sz=15, min_sample_sz=5, pred_interval=.68, conf_min=.5):
+    def avm(self, X, batch_sample_sets=1, latest_production_version=1, max_sample_sz=100, min_sample_sz=15, pred_interval=.68, conf_min=.5):
         """Main method for the BCI avm predictions. 
 
         Arguments:
@@ -426,24 +426,24 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         unit = infer_feature_types(unit)
         y_predd = self._component_graph.predict(unit)
 
-        if match_key in self.master_match_keys:
-            _confs = self.master_match_keys[match_key]
-            resp = pd.DataFrame({})
-            resp['unit_index'] = unit['unit_index']
-            resp['avm'] = y_predd
-            resp['avm_lower'] = _confs['avm_lower']
-            resp['avm_upper'] = _confs['avm_upper']
+        # if match_key in self.master_match_keys:
+        #     _confs = self.master_match_keys[match_key]
+        #     resp = pd.DataFrame({})
+        #     resp['unit_index'] = unit['unit_index']
+        #     resp['avm'] = y_predd
+        #     resp['avm_lower'] = _confs['avm_lower']
+        #     resp['avm_upper'] = _confs['avm_upper']
 
-            if _confs['avm_lower'] is not np.nan:
-                resp = self._get_bounds(resp, y_predd)
-            else:
-                resp['conf'] = [np.nan]
+        #     if _confs['avm_lower'] is not np.nan:
+        #         resp = self._get_bounds(resp, y_predd)
+        #     else:
+        #         resp['conf'] = [np.nan]
 
-            resp['ts'] = [ts]
-            resp['latest_production_version'] = [latest_production_version]
-            resp['latest_staging_version'] = [latest_staging_version]
-            self.l.append(resp)
-            return self
+        #     resp['ts'] = [ts]
+        #     resp['latest_production_version'] = [latest_production_version]
+        #     resp['latest_staging_version'] = [latest_staging_version]
+        #     self.l.append(resp)
+        #     return self
 
         dfs = data[ (data[ 'POSTCODE_AREA' ].astype(str)==unit[ 'POSTCODE_AREA' ].astype(str).values[ 0 ]) & (data[ 'PROPERTY_TYPE_e' ].astype(str)==unit[ 'PROPERTY_TYPE_e' ].astype(str).values[ 0 ])]
 
@@ -457,18 +457,19 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             resp['ts'] = [ts]
             resp['latest_production_version'] = [latest_production_version]
             resp['latest_staging_version'] = [latest_staging_version]
-            self.master_match_keys[match_key] = {
-                'avm_lower': lower,
-                'avm_upper': upper
-            }
+            # self.master_match_keys[match_key] = {
+            #     'avm_lower': lower,
+            #     'avm_upper': upper
+            # }
             self.l.append(resp)
             return self
 
         comp_df = dfs.copy()
         y_trus_all, y_preds_all = [], []
         for n in range(self.batch_sample_sets):
-            dfs = comp_df.sample(frac=.2, replace=True)
+            
             if len(dfs) > self.max_sample_sz:
+                # dfs = comp_df.sample(frac=.2, replace=True)
                 dfs = dfs.sample(self.max_sample_sz)
 
             y_trus = dfs[self.target]
@@ -503,10 +504,10 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         resp['latest_production_version'] = [latest_production_version]
         resp['latest_staging_version'] = [latest_staging_version]
 
-        self.master_match_keys[match_key] = {
-            'avm_lower': lower,
-            'avm_upper': upper
-        }
+        # self.master_match_keys[match_key] = {
+        #     'avm_lower': lower,
+        #     'avm_upper': upper
+        # }
         self.l.append(resp)
         return self
 
